/*
 * Copyright 2012 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.common.dao;

import com.mongodb.DBObject;
import com.redhat.thermostat.common.HostInfo;
import com.redhat.thermostat.common.storage.Chunk;

public class HostInfoConverter {

    public Chunk hostInfoToChunk(HostInfo hostInfo) {
        Chunk chunk = new Chunk(HostInfoDAO.hostInfoCategory, false);
        chunk.put(HostInfoDAO.hostNameKey, hostInfo.getHostname());
        chunk.put(HostInfoDAO.osNameKey, hostInfo.getOsName());
        chunk.put(HostInfoDAO.osKernelKey, hostInfo.getOsKernel());
        chunk.put(HostInfoDAO.cpuCountKey, hostInfo.getCpuCount());
        chunk.put(HostInfoDAO.cpuModelKey, hostInfo.getCpuModel());
        chunk.put(HostInfoDAO.hostMemoryTotalKey, hostInfo.getTotalMemory());
        return chunk;
    }

    public HostInfo fromDBObj(DBObject dbObj) {
        String hostName = (String) dbObj.get("hostname");
        String osName = (String) dbObj.get("os_name");
        String osKernel = (String) dbObj.get("os_kernel");
        String cpuModel = (String) dbObj.get("cpu_model");
        Integer cpuNum = (Integer) dbObj.get("cpu_num");
        Long totalMemory = (Long) dbObj.get("memory_total");
        return new HostInfo(hostName, osName, osKernel, cpuModel, cpuNum, totalMemory);
    }

}
