/*
 * Copyright 2012 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.common.dao;

import java.util.ArrayList;
import java.util.List;

import com.mongodb.BasicDBObject;
import com.mongodb.DB;
import com.mongodb.DBCollection;
import com.mongodb.DBCursor;
import com.mongodb.DBObject;
import com.redhat.thermostat.common.VmClassStat;

public class MongoVmClassStatDAO implements VmClassStatDAO {

    private VmRef ref;
    private DBCollection vmClassStatsCollection;

    private long lastUpdate = Long.MIN_VALUE;

    public MongoVmClassStatDAO(DB db, VmRef vmRef) {
        ref = vmRef;
        vmClassStatsCollection = db.getCollection("vm-class-stats");
    }

    @Override
    public List<VmClassStat> getLatestClassStats() {
        ArrayList<VmClassStat> result = new ArrayList<>();
        BasicDBObject queryObject = new BasicDBObject();
        queryObject.put("agent-id", ref.getAgent().getAgentId());
        queryObject.put("vm-id", Integer.valueOf(ref.getId()));
        if (lastUpdate != Long.MIN_VALUE) {
            // TODO once we have an index and the 'column' is of type long, use
            // a query which can utilize an index. this one doesn't
            queryObject.put("$where", "this.timestamp > " + lastUpdate);
        }
        DBCursor cursor = vmClassStatsCollection.find(queryObject);
        long timestamp;
        Long loadedClasses;
        while (cursor.hasNext()) {
            DBObject current = cursor.next();
            timestamp = (Long) current.get("timestamp");
            loadedClasses = (Long) current.get("loadedClasses");
            int vmId = (Integer) current.get("vm-id");
            result.add(new VmClassStat(vmId, timestamp, loadedClasses));
            lastUpdate = Math.max(timestamp, lastUpdate);
        }

        return result;
    }
}
